# ====== CA: Common Attribute ======
from typing import Final

class CA:
    Account: Final[str] = "aco"
    Activated: Final[str] = "actd"
    Actor: Final[str] = "atr"
    ActorUuid: Final[str] = "atruuid"
    Add: Final[str] = "add"
    AdminBlocked: Final[str] = "admbk"
    Adventurer: Final[str] = "a"
    AdventurerCount: Final[str] = "acnt"
    # AdventurerId: Final[str] = "aid"
    AdventurerUuid: Final[str] = "auuid"
    # AdventurerLaneVersionId: Final[str] = "aevid"
    # AdventurerLaneVersionLogId: Final[str] = "aevlid"
    # AdventurerPuzzleVersionId: Final[str] = "alvid"
    # AdventurerPuzzleVersionLogId: Final[str] = "alvlid"
    # AdventurerSiteVersionId: Final[str] = "aivid"
    # AdventurerSiteVersionLogId: Final[str] = "aivlid"
    All: Final[str] = "all"
    Angle: Final[str] = "agl"
    Answer: Final[str] = "ans"
    # AnswerId: Final[str] = "ansid"
    AnswerUuid: Final[str] = "ansuuid"
    App: Final[str] = "app"
    Api: Final[str] = "api"
    AppBar: Final[str] = "ab"
    Archive: Final[str] = "ahe"
    ArchiveTime: Final[str] = "ahetm"
    ArchiveUuid: Final[str] = "aheuuid"
    Ascending: Final[str] = "asc"  # in SQL
    Attempt: Final[str] = "atp"
    Attribute: Final[str] = "att"
    Auth: Final[str] = "aut"
    Available: Final[str] = "abl"

    Background: Final[str] = "bkg"
    BackPlane: Final[str] = "bkpl"
    Base64: Final[str] = "b64"
    Bean: Final[str] = "ben"
    Blue: Final[str] = "ble"
    Block: Final[str] = "blk"
    Board: Final[str] = "bd"
    Bone: Final[str] = "bn"
    BoardDesign: Final[str] = "bddn"
    # BoardDesignId: Final[str] = "bddnid"
    # BoardId: Final[str] = "bdid"
    Book: Final[str] = "b"
    # BookChapterVersionComboId: Final[str] = "bcvcid"
    # BookHeadVersionId: Final[str] = "bhvid"
    BookHeadVersionUuid: Final[str] = "bhvuuid"
    # BookId: Final[str] = "bid"
    BookList: Final[str] = "bl"
    # BookListId: Final[str] = "blid"
    BookUuid: Final[str] = "buuid"
    BookVersion: Final[str] = "bv"
    # BookVersionId: Final[str] = "bvid"
    BookVersionUuid: Final[str] = "bvuuid"
    BookVersionNo: Final[str] = "bvno"
    Bookkeeping: Final[str] = "bk"
    # BookkeepingId: Final[str] = "bkid"
    Booster: Final[str] = "bsr"
    Button: Final[str] = "btn"

    Cancel: Final[str] = "ccl"
    Card: Final[str] = "crd"
    # CardSnapshotId: Final[str] = "crdsntid"
    CardSnapshotUuid: Final[str] = "crdsntuuid"
    Catalyst: Final[str] = "ctlt"
    Challenge: Final[str] = "che"
    ChallengeMs: Final[str] = "chems"
    ChallengeSec: Final[str] = "chescd"
    Chance: Final[str] = "cae"
    Chapter: Final[str] = "c"
    # ChapterBoneId: Final[str] = "cbnid"
    ChapterBoneUuid: Final[str] = "cbnuuid"
    # ChapterBoneWordId: Final[str] = "cbnwid"
    ChapterBoneWordUuid: Final[str] = "cbnwuuid"
    # ChapterHeadVersionId: Final[str] = "chvid"
    # ChapterId: Final[str] = "cid"
    ChapterUuid: Final[str] = "cuuid"
    ChapterVersion: Final[str] = "cv"
    # ChapterVersionId: Final[str] = "cvid"
    ChapterVersionNo: Final[str] = "cvno"
    # ChapterWordId: Final[str] = "cwid"
    Character: Final[str] = "chr"
    Check: Final[str] = "chk"
    Clear: Final[str] = "cls"
    Click: Final[str] = "clk"
    ClientInfo: Final[str] = "clinf"
    Close: Final[str] = "cl"  # Changed from "cle"
    CloseInit: Final[str] = "cli"
    CloseVowel: Final[str] = "clv"
    Code: Final[str] = "cd"
    Collect: Final[str] = "clt"
    Collected: Final[str] = "cltd"
    CollectedTime: Final[str] = "cltdt"
    Color: Final[str] = "col"
    Column: Final[str] = "cln"
    Combo: Final[str] = "cb"
    Compass: Final[str] = "cps"
    Confirm: Final[str] = "cfm"
    Conquered: Final[str] = "cq"
    ConqueredTime: Final[str] = "cqt"
    Context: Final[str] = "ctt"
    Count: Final[str] = "cnt"
    Cover: Final[str] = "cvr"
    CoverCount: Final[str] = "corcnt"
    CoverLayer: Final[str] = "corlyr"
    CoverLayerCount: Final[str] = "corlyrcnt"
    Create: Final[str] = "ct"
    CreateTime: Final[str] = "crt"
    Cube: Final[str] = "cbe"
    CubeBooster: Final[str] = "cbebsr"
    Current: Final[str] = "curt"

    Data: Final[str] = "dt"
    Database: Final[str] = "db"
    DateOfBirth: Final[str] = "dob"
    DateOfDeath: Final[str] = "dod"
    DbConnect: Final[str] = "dbcn"
    DbQuery: Final[str] = "dbqy"
    Decorator: Final[str] = "dec"
    Default: Final[str] = "def"
    Delete: Final[str] = "del"  # in SQL
    Descending: Final[str] = "desc"  # in SQL
    Description: Final[str] = "des"
    DescriptionFormatted: Final[str] = "desf"
    # DescriptionId: Final[str] = "desid"
    DescriptionIid: Final[str] = "desiid"
    DescriptionPlain: Final[str] = "desp"
    Design: Final[str] = "dn"
    Designer: Final[str] = "dr"
    # DesignerId: Final[str] = "drid"
    DesignerUuid: Final[str] = "druuid"
    Destination: Final[str] = "dtn"
    Details: Final[str] = "dts"
    Dialog: Final[str] = "dlg"
    Difficulty: Final[str] = "dft"
    Drawer: Final[str] = "drw" # Changed from "dwr"

    Egg: Final[str] = "egg"
    EggCount: Final[str] = "eggcnt"
    ElementR: Final[str] = "elmr"
    ElementG: Final[str] = "elmg"
    ElementB: Final[str] = "elmb"
    ElementY: Final[str] = "elmy"
    ElementV: Final[str] = "elmv"
    Email: Final[str] = "em"
    Empty: Final[str] = "emy" # Changed from "ety"
    End: Final[str] = "ed"
    EndFocus: Final[str] = "efc"
    Energy: Final[str] = "eny"
    Enter: Final[str] = "ent"
    EnterTime: Final[str] = "enttm"
    EnterType: Final[str] = "entt"
    Event: Final[str] = "evt"
    EventType: Final[str] = "evttp"
    EventUuid: Final[str] = "evtuuid"
    Example: Final[str] = "exp"
    Extract: Final[str] = "ext"

    Failed: Final[str] = "fail"
    FailedQuest: Final[str] = "failqt"
    Field: Final[str] = "fid"
    Fight : Final[str] = "fgt"
    FightUuid : Final[str] = "fgtuuid"
    Find: Final[str] = "fnd"
    FinalElm: Final[str] = "fnle"
    Finish: Final[str] = "fin"
    Finished: Final[str] = "fied"
    FinishedWord: Final[str] = "fw"
    First: Final[str] = "fst"
    FirstFocus: Final[str] = "fstfc"
    FirstName: Final[str] = "fna"
    Focus: Final[str] = "fcs"
    Focused: Final[str] = "fcsd"
    Focusing: Final[str] = "fcsg"
    FocusOut: Final[str] = "fcot"
    Footer: Final[str] = "ftr"
    Foreground  : Final[str] = "frg"
    Formatted: Final[str] = "fmt"
    FromUuid: Final[str] = "frmuuid"
    FrontEnd: Final[str] = "fe"
    Full: Final[str] = "ful"

    Game: Final[str] = "gm"
    Global: Final[str] = "gb"
    Goal: Final[str] = "gol"
    GoalCount: Final[str] = "golcnt"
    Gold: Final[str] = "g"
    Green : Final[str] = "grn"
    Grid: Final[str] = "gd"
    Group: Final[str] = "gp"

    Hash: Final[str] = "hash"
    Head: Final[str] = "hd"
    HeadVersion: Final[str] = "hv"
    Header: Final[str] = "hdr"
    Height: Final[str] = "ht"
    HiddenLayer: Final[str] = "hdnlyr"
    HiddenLayerCount: Final[str] = "hdnlyrcnt"
    Hide: Final[str] = "hde"
    History: Final[str] = "hy"
    Home: Final[str] = "he"
    HorizontalFlip : Final[str] = "hrzfp"
    HttpStatus: Final[str] = "hts"

    Id: Final[str] = "id"
    Iid: Final[str] = "iid"
    Image : Final[str] = "img"
    Importance: Final[str] = "ipt"
    Index: Final[str] = "ind"
    Info: Final[str] = "inf"
    # InfoLogId: Final[str] = "inflogid"
    InfoRow: Final[str] = "inr"
    # InfoSnapshotId : Final[str] = "infsntid"
    InfoSnapshotUuid : Final[str] = "infsntuuid"
    InfoUpdateTime: Final[str] = "infudtm"
    Init: Final[str] = "it"
    Init12Chars: Final[str] = "i12c"
    Init3Chars: Final[str] = "i3c"
    Init4Chars: Final[str] = "i4c"
    InitFocus: Final[str] = "ifc"
    Input: Final[str] = "inp"
    Item: Final[str] = "im"
    ItemPerPage: Final[str] = "impp"
    IsMentor: Final[str] = "ismr"

    Jwt: Final[str] = "jwt"

    Key: Final[str] = "key"
    Known: Final[str] = "kn"
    KnownWord: Final[str] = "kw"
    KnownWordIid: Final[str] = "kwiid"

    Lane: Final[str] = "e"
    LaneUuid: Final[str] = "euuid"
    LaneChallengeUuid: Final[str] = "echeuuid"
    LaneDesign: Final[str] = "edn"
    LaneDesignUuid: Final[str] = "ednuuid"
    # LaneSiteVersionComboId: Final[str] = "eivcid"
    LaneVersion: Final[str] = "ev"
    # LaneVersionId: Final[str] = "evid"
    LaneVersionUuid: Final[str] = "evuuid"
    Language: Final[str] = "lg"
    Last: Final[str] = "last"
    Last100QuestsPassedCount: Final[str] = "lst100qc"
    Last100QuestsTime: Final[str] = "lst100qt"
    Last10QuestsPassedCount: Final[str] = "lst10qc"
    Last10QuestsTime: Final[str] = "lst10qt"
    Last160QuestsPassedCount: Final[str] = "lst160qc"
    Last160QuestsTime: Final[str] = "lst160qt"
    Last1QuestTime: Final[str] = "lst1qt"
    Last20QuestsPassedCount: Final[str] = "lst20qc"
    Last20QuestsTime: Final[str] = "lst20qt"
    Last320QuestsPassedCount: Final[str] = "lst320qc"
    Last320QuestsTime: Final[str] = "lst320qt"
    Last40QuestsPassedCount: Final[str] = "lst40qc"
    Last40QuestsTime: Final[str] = "lst40qt"
    Last50QuestsPassedCount: Final[str] = "lst50qc"
    Last50QuestsTime: Final[str] = "lst50qt"
    Last5QuestsPassedCount: Final[str] = "lst5qc"
    Last5QuestsTime: Final[str] = "lst5qt"
    Last80QuestsPassedCount: Final[str] = "lst80qc"
    Last80QuestsTime: Final[str] = "lst80qt"
    LastName: Final[str] = "lna"
    LastPassedTime: Final[str] = "lstpt"
    Layer: Final[str] = "lyr"
    Learn: Final[str] = "l"
    # LearnBookId: Final[str] = "lbid"
    # LearnBookVersionId: Final[str] = "lbvid"
    LearnBookVersionUuid: Final[str] = "lbvuuid"
    LearnChapterUuid: Final[str] = "lcuuid"
    # LearnChapterId: Final[str] = "lcid"
    # LearnChapterVersionId: Final[str] = "lcvid"
    # LearnWordId: Final[str] = "lwid"
    LearnWordUuid: Final[str] = "lwuuid"
    LearnerRefWf: Final[str] = "lwf"  # = UserRefWf
    LearnerSaUuid: Final[str] = "lrsauuid"
    LearnerSaLogIid: Final[str] = "lrsaliid"
    # LearnChapterVersionId: Final[str] = 'lcvid'
    Learner: Final[str] = "lr"
    # LearnerId: Final[str] = "lrid"
    LearnerUuid: Final[str] = "lruuid"
    # LearnerSaId: Final[str] = "lrsaid"
    Leave: Final[str] = "le"
    LeaveTime: Final[str] = "letm"
    LeaveType: Final[str] = "letp"
    Length: Final[str] = "lgh"
    Level: Final[str] = "lvl"
    LevelProgress: Final[str] = "lvlp"
    Life: Final[str] = "lf"
    LifeFragment: Final[str] = "lffg"
    Limit: Final[str] = "lmt"
    LimitMove: Final[str] = "lmtmv"
    List: Final[str] = "lt"
    ListNavigator: Final[str] = "ltn"
    ListWordIid: Final[str] = "ltwiid"
    Log: Final[str] = "log"
    LogIid: Final[str] = "logiid"
    Login: Final[str] = "lgn"
    Logo: Final[str] = "loo"
    Logout: Final[str] = "lgo"
    LogUuid: Final[str] = "loguuid"

    Machine: Final[str] = "mch"
    Main: Final[str] = "man"
    MainEventLogUuid : Final[str] = "manevtloguuid"
    MainLayer: Final[str] = "manlyr"
    MainLayerCount: Final[str] = "manlyrcnt"
    Major: Final[str] = "mar"
    Manual: Final[str] = "mal"
    ManualBooster: Final[str] = "malbsr"
    Map: Final[str] = "map"
    MapFrame: Final[str] = "mpf"
    Marker: Final[str] = "mkr"
    Maximum: Final[str] = "max"
    Md5: Final[str] = "md5"
    Mentor: Final[str] = "mr"
    # MentorId: Final[str] = "mrid"
    MentorName: Final[str] = "mrna"
    MentorUuid: Final[str] = "mruuid"
    Menu: Final[str] = "mu"
    Message: Final[str] = "msg"
    MilliSecond: Final[str] = "ms"
    Minimum: Final[str] = "min"
    Minor: Final[str] = "mir"
    Move: Final[str] = "mv"
    My: Final[str] = "my"


    Name: Final[str] = "na"
    # NameId: Final[str] = "naid"
    Navigator: Final[str] = "nav"
    New: Final[str] = "new"
    Next: Final[str] = "nxt"
    NextBookVersion: Final[str] = "nbkv"
    NextPage: Final[str] = "nxp"
    NextSiteVersion: Final[str] = "nilv"
    Not: Final[str] = "not"
    Note: Final[str] = "nt"
    NullSquare: Final[str] = "nulsqe"
    NullSquareCount: Final[str] = "nulsqecnt"


    Obstacle: Final[str] = "otl"
    Ogg: Final[str] = "ogg"
    Ok: Final[str] = "ok"
    Old: Final[str] = "old"
    One: Final[str] = 'one'
    Opacity  : Final[str] = "opy"
    Open: Final[str] = 'opn'
    OrderRank: Final[str] = "odr"
    Others: Final[str] = "ots"
    # OwnerId: Final[str] = "owid"


    Pack: Final[str] = "pak"
    Page: Final[str] = "pg"
    Parameter: Final[str] = "pm"
    Paragraph: Final[str] = "ph"
    ParagraphIid: Final[str] = "phiid"
    PassedCount: Final[str] = "pascnt"
    Passed: Final[str] = "pass"
    Password: Final[str] = "pw"
    Percentage : Final[str] = "ptg"
    Period: Final[str] = "prd"
    Permission : Final[str] = "pmn"
    Piece: Final[str] = "pce"
    PieceCount: Final[str] = "pcecnt"
    PieceLayer: Final[str] = "pcelyr"
    Plain: Final[str] = "pn"
    Play : Final[str] = "py"
    PlayVoice: Final[str] = "pyve"
    PlayVoiceMs : Final[str] = "pyvems"
    Position: Final[str] = "psn"
    Preference: Final[str] = "pfe"
    Previous: Final[str] = 'prs'
    Private: Final[str] = "pvt"
    Privilege: Final[str] = "pvl"
    PreviousPage: Final[str] = "prp"
    Proficiency: Final[str] = 'pfy'
    Public: Final[str] = "pb"
    Publish : Final[str] = "pbh"
    PublishTime: Final[str] = "pbhtm"
    Puzzle: Final[str] = "p"
    PuzzleChallengeUuid: Final[str] = "pcheuuid"
    PuzzleContext: Final[str] = "pctt"
    PuzzleContextUuid: Final[str] = "pcttuuid"
    # PuzzleId: Final[str] = "pid"
    PuzzleUpdateLogUuid : Final[str] = "pudloguuid"
    PuzzleUuid: Final[str] = "puuid"
    PuzzleDesign : Final[str] = "pdn"
    # PuzzleDesignId : Final[str] = "pdnid"
    PuzzleDesignUuid: Final[str] = "pdnuuid"
    PuzzleDesignHash : Final[str] = "pdnhash"

    Query: Final[str] = "qy"
    Quest: Final[str] = "qt"
    QuestBooster: Final[str] = "qtbsr"
    QuestCount: Final[str] = "qtcnt"
    QuestSaAttemptIid: Final[str] = "qsaapiid"
    QuestSaQuestionIid: Final[str] = "qsaqiid"
    QuestSentence: Final[str] = "qstc"
    QuestWfCycleIid: Final[str] = "qwciid"
    QuestWfCycleElmIid: Final[str] = "qwcelmIid"
    Question: Final[str] = "qn"
    Quit: Final[str] = "qut"

    Rate : Final[str] = "rte"
    Read: Final[str] = "rd"
    Red : Final[str] = "red"
    RefTime: Final[str] = "rfLogtm"
    Remove: Final[str] = "rm"
    Request: Final[str] = "req"
    Resource : Final[str] = "res"
    ResourceElement: Final[str] = "reselm"
    ResourceEventLogUuid : Final[str] = "resevtloguuid"
    Response: Final[str] = "rsp"
    Result: Final[str] = "ret"
    Rhumb  : Final[str] = "rhb"
    Right: Final[str] = "r"
    Role: Final[str] = "rol"
    Rotation: Final[str] = "rot"
    Row : Final[str] = "row"

    SaQuestSentenceIid: Final[str] = "saqsiid"
    SaQuestCount: Final[str] = "saqtcnt"
    SaQuestUuid: Final[str] = "saqtuuid"
    Save: Final[str] = "sav"
    Scale: Final[str] = "scl"
    Scene: Final[str] = "scn"
    Search: Final[str] = "sch"
    SearchType: Final[str] = "sht"
    Second: Final[str] = "scd"
    Section: Final[str] = "set"
    SectionIid: Final[str] = "seniid"
    SectionPackage: Final[str] = "spg"
    SectionPackageIid: Final[str] = "spgiid"
    Sentence: Final[str] = "sn"
    SentenceAudio: Final[str] = "sa"
    SentenceAudioIid: Final[str] = "saiid"
    SentenceIid: Final[str] = "sniid"
    SentenceLibrary: Final[str]  = "snl"
    Sequence: Final[str] = "seq"
    Series: Final[str] = "ses"
    Settings: Final[str] = "st"
    Sha1: Final[str] = "sha1"
    Shape: Final[str] = "se"
    Show: Final[str] = "shw"
    Signup: Final[str] = "sgu"
    Similarity: Final[str] = "smy"
    Simple: Final[str] = "smp"
    Site: Final[str] = "s"
    # SiteBoneId: Final[str] = "sbid"
    SiteChallengeUuid: Final[str] = "scheuuid"
    SiteContextUuid: Final[str] = "scttuuid"
    SiteDesign: Final[str] = "sdn"
    SiteDesignUuid: Final[str] = "sdnuuid"
    SiteCount: Final[str] = "scnt"
    # SiteId: Final[str] = "sid"
    SiteIndex: Final[str] = "sind"
    SitePathEnd: Final[str] = "spe"
    # SitePathEndId: Final[str] = "speid"
    SitePathStart: Final[str] = "sps"
    # SitePathStartId: Final[str] = "spsid"
    SitePuzzleVersionComboIid: Final[str] = "spciid"
    SiteTerrain: Final[str] = "stri"
    # SiteTerrainId: Final[str] = "striid"
    SiteTerrainItemMap: Final[str] = "stim"
    # SiteTerrainItemMapId: Final[str] = "stimid"
    SiteTerrainPuzzleMap: Final[str] = "stpm"
    # SiteTerrainPuzzleMapId: Final[str] = "stpmid"
    SiteUuid: Final[str] = "suuid"
    SiteVersion: Final[str] = "sv"
    # SiteVersionId: Final[str] = "svid"
    SiteVersionUuid: Final[str] = "svuuid"
    Size: Final[str] = "siz"
    Slot: Final[str] = "slt"
    Snapshot: Final[str] = "snt"
    # SnapshotId: Final[str] = "sntid"
    SnapshotUuid: Final[str] = "sntuuid"
    SortBy: Final[str] = "stby"
    SortDirection: Final[str] = "stdr"
    SoulSpark: Final[str] = "solspk"
    Space   : Final[str] = "spa"
    Sphere  : Final[str] = "spr"
    Square: Final[str] = "sqe"
    SquareCount: Final[str] = "sqecnt"
    Stand   : Final[str] = "std"
    Star: Final[str] = "str"
    Stars: Final[str] = "strs"
    Start: Final[str] = "str"
    State: Final[str] = "ste"
    Statistics: Final[str] = "stc"
    Status: Final[str] = "sts"
    Summary: Final[str] = "sy"
    Supply: Final[str] = "spl"
    SupplyCount: Final[str] = "splcnt"
    SupplyColumn: Final[str] = "splcln"
    Surface: Final[str] = "sf"
    System: Final[str]= "sys"


    Tag: Final[str] = "tag"
    TagBy: Final[str] = "tgby"
    Target: Final[str] = "tgt"
    Template: Final[str] = "tpe"
    Terrain: Final[str] = "tri"
    Test: Final[str] = "tst"
    Text: Final[str] = "txt"
    TextAuthor: Final[str] = "ta"
    # TextAuthorId: Final[str] = "taid"
    Time: Final[str] = "tm"
    TimeNow: Final[str] = "tnw"
    TimeZone: Final[str] = "tmz"
    Title: Final[str] = "tt"
    TitleIid: Final[str] = "ttiid"
    To: Final[str] = "to"
    Token: Final[str] = "tk"
    TotalCount: Final[str] = "tcnt"
    TotalPlayedVoiceTime: Final[str] = "tpvt"
    TotalCountWithoutFilter: Final[str] = "tcntwtf"
    TotalMs: Final[str] = "tlms"
    TotalSec: Final[str] = "tls"
    ToUuid: Final[str] = "touuid"
    Track : Final[str] = "trk"
    TrackUuid : Final[str] = "trkuuid"
    TrackSpace : Final[str] = "trkspa"
    Transform: Final[str] = "tsf"
    Type: Final[str] = "tp"

    Unknown: Final[str] = "ukn"
    Update: Final[str] = "ud"
    UpdateLogUuid:Final[str] = "udloguuid"
    UpdateTime: Final[str] = "udt"
    Used: Final[str] = "used"
    UsedMs: Final[str] = "usedms"
    UsedSteps: Final[str] = "uss"
    User: Final[str] = "usr"
    # UserId: Final[str] = "uid"
    UserRefWf: Final[str] = "uwf"
    UserUuid : Final[str] = "uuuid"
    Util: Final[str] = "util"
    Uuid : Final[str] = "uuid"

    Value: Final[str] = "val"
    Version: Final[str] = "vn"
    VersionCreate: Final[str] = "vct"
    # VersionId: Final[str] = "vid"
    VersionUuid: Final[str] = "vuuid"
    VersionNo: Final[str] = "vno"
    VerticalFlip : Final[str] = "vtcfp"
    Visited: Final[str] = "vst"
    Visiting: Final[str] = "vstng"
    Voice: Final[str] = "voc"
    VoiceActor: Final[str] = "va"
    VoiceActorIid: Final[str] = "vaiid"
    VoiceLibrary: Final[str] = "vel"
    VoiceSkySite: Final[str] = "vsi"
    VolWorld: Final[str] = "vw"

    Warning: Final[str] = "wag"
    # WfMedian: Final[str] = "wfm"
    WfIid: Final[str] = "wfiid"
    WfIidListOwner: Final[str] = "wfiidltow"
    WfMedian: Final[str] = "wfm"
    Width: Final[str] = "wh"
    WindRose: Final[str] = "wr"
    Word: Final[str] = "w"
    WordBookLibrary: Final[str] = "wbl"
    WordFrequency: Final[str] = "wf"
    WordIid: Final[str] = "wiid"
    WordIidList: Final[str] = "wiidlst"
    WordIndexList: Final[str] = "windlst"
    WordLearn: Final[str] = 'wl'
    WordLearningState: Final[str] = "wls"
    WordList: Final[str] = "wl"
    WordListIid: Final[str] = "wliid"
    WordListOwner: Final[str] = "wlo"
    WordListOwnerIid: Final[str] = "wloiid"
    WordListOwnerVersionIid: Final[str] = "wloviid"
    WordSimilarity: Final[str] = "wsmy"
    WordsToUpgrade: Final[str] = "wtug"
    WordTags: Final[str] = "wtgs"

    X: Final[str] = "x"
    Xy: Final[str] = "xy"

    Y: Final[str] = "y"

    ___Error___: Final[str] = "err"
