from enum import IntEnum

class SurfaceType(IntEnum):

    Empty = 0,

    Grass_1 = 101,
    Grass_2 = 102,
    Grass_3 = 103,
    Grass_4 = 104,
    Grass_5 = 105,
    Grass_6 = 106,
    Grass_7 = 107,

    Brick_1 = 201,
    Brick_2 = 202,
    Brick_3 = 203,
    Brick_4 = 204,
    Brick_5 = 205,

